Index: kernel/generic/src/time/clock.c
===================================================================
--- kernel/generic/src/time/clock.c	(revision 31d8e103d56f8142eb714a22e4d2cbd7e22e5b5a)
+++ kernel/generic/src/time/clock.c	(revision 6fa4888bc8c769ce4699fac1eafd8f9c5d9dac46)
@@ -42,5 +42,4 @@
 #include <time/clock.h>
 #include <time/timeout.h>
-#include <arch/types.h>
 #include <config.h>
 #include <synch/spinlock.h>
@@ -58,14 +57,10 @@
 #include <ddi/ddi.h>
 
-/** Physical memory area of the real time clock. */
+/* Pointer to variable with uptime */
+uptime_t *uptime;
+
+/** Physical memory area of the real time clock */
 static parea_t clock_parea;
 
-/* Pointers to public variables with time */
-struct ptime {
-	unative_t seconds1;
-	unative_t useconds;
-	unative_t seconds2;
-};
-struct ptime *public_time;
 /* Variable holding fragment of second, so that we would update
  * seconds correctly
@@ -87,13 +82,12 @@
 		panic("Cannot allocate page for clock");
 	
-	public_time = (struct ptime *) PA2KA(faddr);
-
-        /* TODO: We would need some arch dependent settings here */
-	public_time->seconds1 = 0;
-	public_time->seconds2 = 0;
-	public_time->useconds = 0; 
+	uptime = (uptime_t *) PA2KA(faddr);
+	
+	uptime->seconds1 = 0;
+	uptime->seconds2 = 0;
+	uptime->useconds = 0; 
 
 	clock_parea.pbase = (uintptr_t) faddr;
-	clock_parea.vbase = (uintptr_t) public_time;
+	clock_parea.vbase = (uintptr_t) uptime;
 	clock_parea.frames = 1;
 	clock_parea.cacheable = true;
@@ -117,14 +111,14 @@
 {
 	if (CPU->id == 0) {
-		secfrag += 1000000/HZ;
+		secfrag += 1000000 / HZ;
 		if (secfrag >= 1000000) {
 			secfrag -= 1000000;
-			public_time->seconds1++;
+			uptime->seconds1++;
 			write_barrier();
-			public_time->useconds = secfrag;
+			uptime->useconds = secfrag;
 			write_barrier();
-			public_time->seconds2 = public_time->seconds1;
+			uptime->seconds2 = uptime->seconds1;
 		} else
-			public_time->useconds += 1000000/HZ;
+			uptime->useconds += 1000000 / HZ;
 	}
 }
